#
# spec file for package libdlm
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%if 0%{?suse_version}
%define _libexecdir %{_libdir}
%endif
%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version}
%define pkg_group System Environment/Daemons
%else
%define pkg_group Productivity/Clustering/HA
%endif

Name:           libdlm
Summary:        Application interface to the kernel's distributed lock manager
License:        GPL-2.0-only AND GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Clustering/HA
Version:        4.2.0
Release:        150600.1.3
URL:            https://pagure.io/dlm/
Source:         https://releases.pagure.org/dlm/dlm-%{version}.tar.gz

##################
#upstream patch
Patch0001:      0001-Revert-treewide-add-fcf-protection-full-to-CFLAGS.patch
Patch0002:      0002-dlm_controld-increase-uevent-recv-buffer.patch
Patch0003:      0003-dlm_controld-constify-lsnames.patch
Patch0004:      0004-dlm_controld-better-uevent-filtering.patch
Patch0005:      0005-libdlm_lt-fix-pc-file.patch
Patch0006:      0006-dlm_tool-add-fail-functionality-if-dump-failed.patch
Patch0007:      0007-dlm_controld-always-create-logdir.patch
Patch0008:      0008-dlm_controld-move-processing-of-saved-messages-to-pl.patch
Patch0009:      0009-dlm_controld-remove-ls-parameter.patch
Patch0010:      0010-dlm_controld-constify-timeval-of-dt_usec.patch
Patch0011:      0011-dlm_controld-add-gcc-format-printf-attribute-to-log_.patch
Patch0012:      0012-dlm_controld-use-write_result.patch
Patch0013:      0013-dlm_controld-be-sure-we-stop-lockspaces-before-shutd.patch
Patch0014:      0014-dlm_controld-constify-name_in-in-log_level.patch
Patch0015:      0015-dlm_controld-initialize-waiter-flags.patch
Patch0016:      0016-dlm_controld-get-rid-of-unnecessary-memset.patch
Patch0017:      0017-dlm_controld-remove-unnecessary-list_empty-check.patch
Patch0018:      0018-dlm_controld-set-posix_lock-flags-to-zero.patch
Patch0019:      0019-dlm_controld-init-plocks_data-to-zero.patch
Patch0020:      0020-dlm_tool-fix-missing-fclose-calls.patch

# suse special patch
Patch1001:      0001-makefile-for-diff-arch.patch
Patch1002:      0002-remove-sd-notify.patch
Patch1003:      0003-bnc#874705-nodes-without-quorum.patch
Patch1004:      0004-man-dlm.conf-add-note-that-the-file-is-not-creat.patch
Patch1005:      bug-1191734_0015-Revert-dlm_controld-add-version-check-for-libquorum.patch
Patch1006:      bug-1191734_0016-Revert-dlm_controld-use-new-quorum-api-to-detect-mis.patch
Patch1007:      0005-build-dlm_controld-disable-annobin-plugin.patch
Patch1008:      bug-1212767-dlm_controld-remove-unnecessary-header-include.patch
##################

BuildRequires:  fdupes
BuildRequires:  glib2-devel
BuildRequires:  libcorosync-devel
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  pkgconfig(pacemaker)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
Recommends:     dlm-kmp

%description
Libraries and tools that allow applications, particularly filesystems
like OCFS2, to interface with the in-kernel distributed lock manager.

%package -n     libdlm3
Summary:        Application interface to the kernel's distributed lock manager
# libdlm2 (openSUSE 11.2) also contained libdlm*.so.3
License:        GPL-2.0-only AND GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries
Obsoletes:      libdlm2 < 2.99
Conflicts:      libdlm2 < 2.99

%description -n libdlm3
Libraries and tools that allow applications, particularly filesystems
like OCFS2, to interface with the in-kernel distributed lock manager.

%package        devel
Summary:        Development files for the kernel's distributed lock manager
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       libdlm3 = %{version}

%description devel
Libraries and tools that allow applications, particularly filesystems
like OCFS2, to interface with the in-kernel distributed lock manager.

%prep
%autosetup -p1 -n dlm-%{version}

%build
echo "V_%version { global: *; };" >dlm.ver
export CFLAGS="%optflags"
export LDFLAGS="-Wl,--version-script=$PWD/dlm.ver"
make all UDEVDIR="%{_udevrulesdir}"
###########################################################

%install
###########################################################
%make_install UDEVDIR="%{_udevrulesdir}"
mkdir -p $RPM_BUILD_ROOT%{_datadir}/doc/packages/libdlm-%{version}

install -Dm 0644 init/dlm.service $RPM_BUILD_ROOT%{_unitdir}/dlm.service
install -Dm 0644 init/dlm.sysconfig $RPM_BUILD_ROOT%{_fillupdir}/sysconfig.dlm
%fdupes %{buildroot}/%{_prefix}

###########################################################

%post
%fillup_only -n dlm
%{?udev_rules_update}
%service_add_post dlm.service

%preun
%service_del_preun dlm.service

%pre
%service_add_pre dlm.service

%postun
%service_del_postun dlm.service

%post   -n libdlm3 -p /sbin/ldconfig
%postun -n libdlm3 -p /sbin/ldconfig

%files
%dir %{_datadir}/doc/packages/libdlm-%{version}
%{_udevrulesdir}/51-dlm.rules
%{_sbindir}/dlm_controld
%{_sbindir}/dlm_stonith
%{_sbindir}/dlm_tool
%{_datadir}/man/man8/*.gz
%{_datadir}/man/man3/*.gz
%{_datadir}/man/man5/*.gz
%{_datadir}/doc/packages/libdlm-%{version}
%{_unitdir}/dlm.service
%{_fillupdir}/sysconfig.dlm

%files -n libdlm3
%{_libdir}/libdlm.so.*
%{_libdir}/libdlm_lt.so.*
%{_libdir}/libdlmcontrol.so.*

%files devel
%{_libdir}/libdlm*.so
%{_libdir}/pkgconfig/libdlm.pc
%{_libdir}/pkgconfig/libdlm_lt.pc
%{_libdir}/pkgconfig/libdlmcontrol.pc
%{_includedir}/libdlm.h
%{_includedir}/libdlmcontrol.h

%changelog
* Wed Sep 20 2023 heming.zhao@suse.com
- update libdlm to latest code (e5ca08c20e6f) (jsc#PED-6362)
  * remove patches which replaced by upstream patch
  - 0007-Revert-treewide-add-fcf-protection-full-to-CFLAGS.patch
  * change patch name
  - 0006-dlm_controld-remove-unnecessary-header-include.patch
    + bug-1212767-dlm_controld-remove-unnecessary-header-include.patch
  * add upstream patch
    + 0001-Revert-treewide-add-fcf-protection-full-to-CFLAGS.patch
    + 0002-dlm_controld-increase-uevent-recv-buffer.patch
    + 0003-dlm_controld-constify-lsnames.patch
    + 0004-dlm_controld-better-uevent-filtering.patch
    + 0005-libdlm_lt-fix-pc-file.patch
    + 0006-dlm_tool-add-fail-functionality-if-dump-failed.patch
    + 0007-dlm_controld-always-create-logdir.patch
    + 0008-dlm_controld-move-processing-of-saved-messages-to-pl.patch
    + 0009-dlm_controld-remove-ls-parameter.patch
    + 0010-dlm_controld-constify-timeval-of-dt_usec.patch
    + 0011-dlm_controld-add-gcc-format-printf-attribute-to-log_.patch
    + 0012-dlm_controld-use-write_result.patch
    + 0013-dlm_controld-be-sure-we-stop-lockspaces-before-shutd.patch
    + 0014-dlm_controld-constify-name_in-in-log_level.patch
    + 0015-dlm_controld-initialize-waiter-flags.patch
    + 0016-dlm_controld-get-rid-of-unnecessary-memset.patch
    + 0017-dlm_controld-remove-unnecessary-list_empty-check.patch
    + 0018-dlm_controld-set-posix_lock-flags-to-zero.patch
    + 0019-dlm_controld-init-plocks_data-to-zero.patch
    + 0020-dlm_tool-fix-missing-fclose-calls.patch
  * WHAT'S NEW for this update
    + dlm_tool: fix missing fclose calls
    + dlm_controld: init plocks_data to zero
    + dlm_controld: set posix_lock flags to zero
    + dlm_controld: remove unnecessary list_empty check
    + dlm_controld: get rid of unnecessary memset
    + dlm_controld: initialize waiter->flags
    + dlm_controld: be sure we stop lockspaces before shutdown
    + dlm_controld: use write_result()
    + dlm_controld: remove ls parameter
    + dlm_controld: move processing of saved messages to plock level
    + dlm_controld: always create logdir
    + dlm_tool: add fail functionality if dump failed
    + libdlm_lt: fix pc file
    + dlm_controld: better uevent filtering
    + dlm_controld: increase uevent recv buffer
* Tue Jun 27 2023 ana.guerrero@suse.com
- Update to v4.2.0
  * remove patches included upstream
  + bug-1191734_0001-libdlm-add-stdint.h-to-api-header.patch
  + bug-1191734_0002-dlm_controld-create-var-parent-directories.patch
  + bug-1191734_0003-stonith_helper-fix-build.patch
  + bug-1191734_0004-plock-move-clear-waiter-to-debug-info.patch
  + bug-1191734_0005-treewide-try-to-resolve-symbols-at-linking-time.patch
  + bug-1191734_0006-dlm_controld-add-version-check-for-libquorum.patch
  + bug-1191734_0007-dlm_tool-man-add-command-joinleave-USAGE.patch
  + bug-1191734_0008-man-add-reload_config-in-dlm_tool-dlm.conf.patch
  + bug-1191734_0009-add-new-dlm_tool-command-reload_config.patch
  + bug-1191734_0010-dlm_tool-man-add-new-command-set_config.patch
  + bug-1191734_0011-dlm_tool-dlm_controld-add-new-feature-set_config.patch
  + bug-1191734_0012-fix-some-minor-bugs.patch
  + bug-1191734_0013-dlm_controld-fix-string-copies.patch
  + bug-1191734_0014-man-page-updates.patch
  * patch to disable annobin (still not available in openSUSE)
  + 0005-build-dlm_controld-disable-annobin-plugin.patch
  * patch to remove unnecesary header (boo#1212767)
  + 0006-dlm_controld-remove-unnecessary-header-include.patch
  * patch to remove -fcf-protection=full, not supported in SLE15
  + 0007-Revert-treewide-add-fcf-protection-full-to-CFLAGS.patch
* Fri May 27 2022 ygao@suse.com
- Adjust BuildRequires libpacemaker-devel -> pkgconfig(pacemaker)
* Mon Oct 18 2021 heming.zhao@suse.com
- Update to v4.1.0+ (bsc#1191734)
  * include some fixes/enhancements upstream patches based on 4.1.0 tag
  + bug-1191734_0001-libdlm-add-stdint.h-to-api-header.patch
  + bug-1191734_0002-dlm_controld-create-var-parent-directories.patch
  + bug-1191734_0003-stonith_helper-fix-build.patch
  + bug-1191734_0004-plock-move-clear-waiter-to-debug-info.patch
  + bug-1191734_0005-treewide-try-to-resolve-symbols-at-linking-time.patch
  + bug-1191734_0006-dlm_controld-add-version-check-for-libquorum.patch
  + bug-1191734_0007-dlm_tool-man-add-command-joinleave-USAGE.patch
  + bug-1191734_0008-man-add-reload_config-in-dlm_tool-dlm.conf.patch
  + bug-1191734_0009-add-new-dlm_tool-command-reload_config.patch
  + bug-1191734_0010-dlm_tool-man-add-new-command-set_config.patch
  + bug-1191734_0011-dlm_tool-dlm_controld-add-new-feature-set_config.patch
  + bug-1191734_0012-fix-some-minor-bugs.patch
  + bug-1191734_0013-dlm_controld-fix-string-copies.patch
  + bug-1191734_0014-man-page-updates.patch
  * patch for compatible with corosync-2.4.5+
  + bug-1191734_0015-Revert-dlm_controld-add-version-check-for-libquorum.patch
  + bug-1191734_0016-Revert-dlm_controld-use-new-quorum-api-to-detect-mis.patch
  * drop 2 patches which are already included in upstream code
  - cluster-ringid-seq.patch
  - sysmacros.patch
  * change name and modify patch for code changed
  - dlm_controld-add-note-that-the-dlm-file-is-not-creat.patch
  + 0004-man-dlm.conf-add-note-that-the-file-is-not-creat.patch
  * change libdlm.spec to seperate upsteam patch and suse special patch
* Wed Oct 14 2020 jengelh@inai.de
- Do build with SUSE's %%optflags.
- Abolish historic specfile constructs.
- Rework libdlm3 require with a shared library version
  tag instead so it propagates to all consuming packages.
* Wed Oct 14 2020 ghe@suse.com
- Add require libdlm3 (bsc#1177658)
* Mon Sep 21 2020 ghe@suse.com
- Add dependency relationship between libdlm and dlm-kmp (bsc#1121380)
* Tue Sep 15 2020 ghe@suse.com
- Add notes in dlm.conf man page (bsc#1175812)
  * add dlm_controld-add-note-that-the-dlm-file-is-not-creat.patch
* Fri May 15 2020 ghe@suse.com
- Support uint64_t corosync ringid (bsc#1168771)
  * add cluster-ringid-seq.patch
* Mon Aug  5 2019 ghe@suse.com
- Update to v4.0.9
  * include some fixes/enhancements for dlm_controld (bsc#1144793)
  * source moved to https://pagure.io/dlm
  * drop 0004-bsc#1098449-dlm_stonith-explicitly-use-libstonithd.patch
* Thu Nov 15 2018 ygao@suse.com
- Explicitly use and link libstonithd from libpacemaker3 (bsc#1098449)
  * 0004-bsc#1098449-dlm_stonith-explicitly-use-libstonithd.patch
* Mon Aug  6 2018 schwab@suse.de
- sysmacros.patch: Include <sys/sysmacros.h> for minor
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Tue Feb 14 2017 jengelh@inai.de
- Use source URL; drop redundant %%clean section;
  rectify RPM groups; run fdupes to merge duplicate files.
* Sat Feb  4 2017 zren@suse.com
- Update to v4.0.7
  * bsc#1023595: libdlm: upgrade version to 4.0.7
- Re-add the dropped bsc numbers to follow the factory-first policy
  * take Factory fixes for SLE12 (boo#944795, bsc#944797)
* Mon Jul 25 2016 zren@suse.com
- Update to v4.0.6
  * In v4.0.4, there's a stupid and severe bug so that upstream
  released v4.0.5 soon with an urgent fix
  * Upstream merged our fix for bsc#977201 with release v4.0.6,
  so I still use the 2 below bugs for this updates:
  * bsc#967332: libdlm: package update to v4.0.4
  * bsc#977201: output of `dlm_tool ls` should distinguish causes
  for "wait fencing" message
- Drop patches
  * bnc#875122dlm_controld-fix-long-name-in-log-entry.patch
  * build-dlm_stonith.patch
- Rename patches more readable
  * remove: Makefile-for-diff-arch.patch, remove-sd-notify.patch,
  bnc#874705nodes-without-quorum.patch
  * add: 0001-makefile-for-diff-arch.patch,
  0002-remove-sd-notify.patch,
  0003-bnc#874705-nodes-without-quorum.patch
* Mon Feb 15 2016 zren@suse.com
- Update to V4.0.4
  * Remove build-dlm_stonith.patch
  * Reove bnc#875122dlm_controld-fix-long-name-in-log-entry.patch
* Fri May  1 2015 jengelh@inai.de
- Avoid running sh for %%post ldconfig
- Default to implicit -n for %%setup
* Sun Apr 12 2015 crrodriguez@opensuse.org
- Move udev rules to %%{_udevrulesdir}, packages should
  not ship files in /etc/udev/rules.d which is reserved
  for the sysadmin.
* Fri Nov 14 2014 dimstar@opensuse.org
- BuildRequire pkgconfig(systemd) instead of systemd-devel.
* Wed May 21 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Tue May 20 2014 lzhong@suse.com
- fix different behavior when nodes without quorum
  + bnc#874705nodes-without-quorum.patch
* Mon Apr 28 2014 lzhong@suse.com
- dlm_controld print out error format message(bnc#875122)
  + bnc#875122dlm_controld-fix-long-name-in-log-entry.patch
* Mon Mar 31 2014 lzhong@suse.com
- dlm_controld notifies systemd(bnc#870626)
  + remove-sd-notify.patch
* Sat Sep  7 2013 rgoldwyn@suse.com
- Build dlm_stonith to prox fencing for pacemaker
  + build-dlm_stonith.patch
- Remove patch to use default fscontrol using sysconfig
  - libdlm-enable-fscontrol.patch
* Thu Aug  1 2013 lzhong@suse.com
- Update to V4.0.2
* Tue Jul 23 2013 lzhong@suse.com
- Update to V4.0.1(openSuse13.1)
  + file a patch for opensuse build service
- Remove patches from sle11sp3 for either merged in the upstream
  or obsoleted.
  - bnc804707-reduce-RR-priority.patch
  - bnc777137-fix-plock-dev_write_no_op.patch
  - libdlm-gcc47.patch
  - libdlm-pacemaker.patch
* Mon Jun 24 2013 ygao@suse.com
- dl_controld: libdlm-pacemaker.patch
  * Replace use of send_ais_text() with send_cluster_text()
  * Replace use of ais_dispatch() with plugin_dispatch()
  * Replace use of crm_peer_id_cache with crm_peer_cache
* Mon May 27 2013 tserong@suse.com
- Replace NAME= with SYMLINK+= in udev rules (bnc#779718)
  + use-symlink-in-udev-rules.patch
* Thu Mar 28 2013 dmzhang@suse.com
- reduce dlm_controld priority to RR(1). (bnc#804707)
* Fri Feb 22 2013 lmb@suse.com
- Make sure we poll the right fd for AIS notifications to avoid spinning
  (bnc#803746)
* Mon Jan 28 2013 coolo@suse.com
- small cleanup of spec file
* Mon Jan 28 2013 xli@suse.com
- fix the build issue on openSuSE 12.3 Milestone 1 (bnc#798263)
  add bnc798263-fix-opensuse123-compile-error.patch
* Fri Aug 24 2012 jjzhang@suse.com
- dlm_controld: fix plock dev_write no op (bnc#777137)
  add bnc777137-fix-plock-dev_write-no-op.patch
* Sat Jun 23 2012 ygao@suse.com
- dlm_controld: Replace use of crm_is_member_active() with the new
  crm_is_peer_active() from pacemaker > 1.1.7
* Thu May 24 2012 idonmez@suse.com
- Fix build with gcc 4.7
* Fri Dec 16 2011 tserong@suse.com
- fix build with current pacemaker
  (/usr/include/pacemaker/crm/common/stack.h
  moved to
  /usr/include/pacemaker/crm/cluster/stack.h)
* Sun Nov 13 2011 coolo@suse.com
- add libtool as explicit buildrequire to avoid implicit dependency from prjconf
* Tue Sep 20 2011 tserong@suse.com
- dlm_controld: fix build with old (< 3.0) kernel headers
- dlm_controld: clear waiting plocks for closed files
- dlm_controld: Introduce RB tree for improving plock resources searching
  efficiency
- dlm_controld: RB tree implementation borrowed from the kernel source
- dlm_controld: remove oom_adj
- dlm_controld: ignore plocks until checkpoint time
- dlm_controld: fix plock signature in stored message
- dlm_controld: fix plock owner syncing
- dlm_controld: fix plock owner in checkpoints
- dlm_controld: fix plock checkpoint signatures
- dlm_controld: wrong fencing time comparison
- dlm_controld.pcmk: Prevent use-of-NULL by checking the node has a valid
  address before adding it to configfs
- dlm_controld: always return error if the daemon is not ready to operate
* Tue Aug 30 2011 andrea.turrini@gmail.com 
- Fixed typos and removed duplicated "Authors:" entry in
  descriptions of libdlm.spec
* Mon May 23 2011 crrodriguez@opensuse.org
- Avoid adding build time in binaries, breaks build-compare.
* Tue Feb  8 2011 tserong@novell.com
- bnc-634240_reset-fs_notified.diff : Reset fs_notified when check_fs_done
* Thu Aug 19 2010 tserong@novell.com
- Revert previous change ("allow libdlm to compile with new
  pacemaker version")
* Mon Jun 14 2010 lmb@novell.com
- Allow libdlm to compile with new pacemaker version.
* Tue May 18 2010 tserong@novell.com
- Reverted libdlm-bug-603685-v2.diff (bug now fixed in Pacemaker)
* Fri May 14 2010 lmb@novell.com
- libdlm-bug-603685-v2.diff: fix dlm_controld.pcmk member processing
  (bnc#603685)
* Mon Apr 26 2010 coly.li@suse.de
- update from upstream (cs fae6ee39)
  - dlm_controld: don't log errors after disabling plocks
  - dlm_controld: don't skip unlinking checkpoint
  - dlm_controld: set last_plock_time for ownership operations
  - dlm_controld: add plock checkpoint signatures
  - dlm_controld: check all messages against enable options
  - dlm_controld: avoid full plock unlock when no resource exists
* Wed Mar 24 2010 coyli@novell.com
- update from upstream:
  - dlm_controld: set rmem for sctp
  - misc: update copyright year and owners
  - man pages: dlm_tool and dlm_controld
  - dlm_controld/libdlmcontrol/dlm_tool: separate plock debug buffer
  - dlm_controld: add more fs_notified debugging
* Fri Feb  5 2010 coyli@novell.com
- delete 64bytes_lvb_len.diff (bnc#573460)
* Wed Jan 27 2010 lmb@novell.com
- Remove libdlm2 on upgrade.
* Tue Dec  8 2009 coyli@novell.com
- 64bytes_lvb_len.diff: change DLM_LVB_LEN to 64 bytes (bnc#515645)
* Wed Dec  2 2009 coyli@novell.com
- remove already-in-upstream patches from package
* Wed Dec  2 2009 coyli@novell.com
- update to upstream commit 7ad436ba4a7d68a79510fd6c033568b6bb100191.
  not pass compiling yet
* Thu Nov 26 2009 coyli@novell.com
- upgrade package version number from 2.99.08 to 3.00.01, no code
  modified.
* Tue Sep 29 2009 "lmb@novell.com"
- libdlm-lockspace-fs_notify.diff: fix a race which could lead to an
  infinite logging loop (bnc#532406).
* Tue Sep 22 2009 "lmb@novell.com"
- dlm-no-quorum-default.diff: change quorum handling to allow cluster to
  shutdown nodes one-by-one (bnc#541042).
* Thu Sep  3 2009 "lmb@novell.com"
- dlm-debug.diff: Include the lockspace name in syslog().
* Thu Aug 27 2009 "lmb@novell.com"
- dlm-plock-optimization.diff: allow plocks to revert back to single
  node mode (bnc#497176).
* Mon Aug 10 2009 lmb@novell.com
- libdlm-lockspace-recovery.patch: ensure that all lock spaces are
  recovered (bnc#528425).
* Wed Jul 29 2009 coly.li@suse.de
- add ocfs2-kmp to libdlm requires, since fs/dlm will be integrated
  into ocfs2-kmp.
* Tue Jul 21 2009 lmb@novell.com
- Fix compilation with new pacemaker code.
* Tue Mar 31 2009 abeekhof@suse.de
- Update for HAE11-RC9
- Bug bnc#490418 - Reduce the amount of logging while waiting for nodes to be shot
* Fri Mar 20 2009 abeekhof@suse.de
- Split the SUSE specific patch from the parts that have
  been submitted upstream
- Correctly log the result of calls to crm_terminate_member_no_mainloop()
* Thu Mar 19 2009 abeekhof@suse.de
- Fix race condition when creating configfs entries for
  cluster peers
* Fri Mar 13 2009 abeekhof@suse.de
- All previous patches are now upstream
- Update to upstream: cfd58b24b8bb17087e19a73139cf966135e78bec
  - dlm_controld (pcmk) - Use a Pacemaker library function for kicking nodes from the cluster
  - dlm_tool: fix lockdebug parsing of first_lkid
  - dlm_controld: default to no plock rate limit
  - dlm_controld: don't exit from query thread
  - dlm_controld: finalize ckpt handle
  - dlm_controld: cpg_finalize
  - dlm_controld: use quorum instead of votequorum
* Tue Feb 17 2009 abeekhof@suse.de
- BNC#476449 - Correctly return the current fencing status
* Fri Feb  6 2009 abeekhof@suse.de
- Switch to stand-alone libdlm code-base
- Update to upstream: af52b7bb26a05a8f73d1076254e178b02ed192cd
- Update to patch-level: a85c21afc4c99dc2aee8f7e7e356f25133c4d4ad
  - Implement fencing hooks for Pacemaker based clusters
  - Leverage more funcaitonality from Pacemaker libraries
  - Add pkgconfig entries
  - dlm_controld/gfs_controld: read lockless resources from ckpts
  - dlm_controld/gfs_controld: dump unused resources
  - dlm_controld/gfs_controld: fix plock rate limiting
  - dlm_controld/gfs_controld: plock config paths
  - dlm_controld/gfs_controld: plock dump display resource owner
  - dlm_controld: recv error checking
  - dlm_controld: clear plock syncing flags
* Tue Nov 11 2008 abeekhof@suse.de
- Update to upstream bd261c8e51f3b5406f22bbb00b76f6da8722412d
  - fix plock dump
  - fix fencing checks which weren't happening
  - fix confchg/message processing, must be done after each individual confchg/message
  - init logging after fork to avoid ugly interaction with logging threads
  - fix usage of the query thread mutex
  - fix usage of realloc in deadlock code
  - join should return error without fence domain
* Thu Oct  9 2008 abeekhof@suse.de
- Update to upstream b6d73f5752306d635f306036438af1fcf26f4332
  - Adds protocol negotiation which important for future compatability
  - Miscelaneous bug fixes
* Mon Sep 15 2008 abeekhof@suse.de
- Reference newly created shared library packages as build dependancies
* Mon Sep  8 2008 abeekhof@suse.de
- Move documentation to acceptable location
* Tue Sep  2 2008 abeekhof@suse.de
- Extra %%dir entries n the %%files section to make autobuild happy
* Mon Aug 25 2008 abeekhof@suse.de
- version 2.99.08-2
- make sure local_nodeid is set correctly for dlm_controld
* Tue Aug 19 2008 abeekhof@suse.de
- version 2.99.08-1
- Initial package check-in
